@@ -29,4 +29,12 @@ def test_practitioner_fail_on_schema(spark_session: SparkSession) -> None:
             assert e.exceptions[0].compare_path == Path(
                 "/foo/output/temp/result/compare_schema_output.json.command"
             )
+            compare_file_full_path = data_dir.joinpath(
+                "output/temp/result/compare_schema_output.json.command"
+            )
+            with open(compare_file_full_path, "r") as file:
+                print(
+                    f"------- compare file: {compare_file_full_path} ---------"
+                )
+                print(file.read())
             raise
